/*
* TeamSpeak 3 server minimal sample
*
* Copyright (c) 2007-2017 TeamSpeak-Systems
*/
#include "common.h"

#include <teamspeak/public_definitions.h>
#include <teamspeak/serverlib.h>
#include <teamspeak/serverlib_publicdefinitions.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int main() {
    /* Create struct for callback function pointers */
    struct ServerLibFunctions funcs;

    /* Initialize all callbacks with NULL */
    memset(&funcs, 0, sizeof(struct ServerLibFunctions));

    /* Initialize server lib with callbacks */
    CHECK_ERROR_FATAL(ts3server_initServerLib(&funcs, LogType_CONSOLE, NULL));

    /* Create virtual server using default port 9987 with max 10 slots */
    /* listen on any address on ipv4 and ipv6 (it is also possible to enter multiple ipv4 and ipv6 addresses here) */
    uint64 server_id;
    CHECK_ERROR_FATAL(ts3server_createVirtualServer(9987, "0.0.0.0, ::", "TeamSpeak SDK Testserver", "", 10, &server_id));

    /* Create Channel Part */
    uint64 channelParentID = 0;
    uint64 newChannel_id;
    
    /* Set data of new channel. Use channelID of 0 for creating channels. */
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, 0, CHANNEL_NAME,                "Test channel name"));
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, 0, CHANNEL_TOPIC,               "Test channel topic"));
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, 0, CHANNEL_DESCRIPTION,         "Test channel description"));
    CHECK_ERROR(ts3server_setChannelVariableAsInt   (server_id, 0, CHANNEL_FLAG_PERMANENT,      1));
    CHECK_ERROR(ts3server_setChannelVariableAsInt   (server_id, 0, CHANNEL_FLAG_SEMI_PERMANENT, 0));

    /* Flush changes to server */
    CHECK_ERROR(ts3server_flushChannelCreation(server_id, channelParentID, &newChannel_id));

    printf("\nCreated channel: %llu\n\n", (unsigned long long)newChannel_id);

    /* Change Channel Variables Part */
    char* name;

	printf("Channel ID: %llu\n\n", (unsigned long long)newChannel_id);

    /* First we display the channel variables from channel creation */

	if (CHECK_ERROR(ts3server_getChannelVariableAsString(server_id, newChannel_id, CHANNEL_NAME, &name)) == true)
	{
		printf("Name of channel %llu\n\n is: %s\n", (unsigned long long)newChannel_id, name);
    	ts3server_freeMemory(name);
	}
	if (CHECK_ERROR(ts3server_getChannelVariableAsString(server_id, newChannel_id, CHANNEL_TOPIC, &name)) == true)
	{
		printf("Topic of channel %llu\n\n is: %s\n", (unsigned long long)newChannel_id, name);
    	ts3server_freeMemory(name);
	}
	if (CHECK_ERROR(ts3server_getChannelVariableAsString(server_id, newChannel_id, CHANNEL_DESCRIPTION, &name)) == true)
	{
        printf("Description of channel %llu\n\n is: %s\n", (unsigned long long)newChannel_id, name);
    	ts3server_freeMemory(name);
	}

    /* Now we change the variables */

    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, newChannel_id, CHANNEL_NAME,                "New channel name"));
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, newChannel_id, CHANNEL_TOPIC,               "New channel topic"));
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, newChannel_id, CHANNEL_DESCRIPTION,         "New channel description"));

    /* And flush the changes */
    CHECK_ERROR(ts3server_flushChannelVariable(server_id, newChannel_id));

    /* And we can display the changed variables */
    if (CHECK_ERROR(ts3server_getChannelVariableAsString(server_id, newChannel_id, CHANNEL_NAME, &name)) == true)
	{
		printf("Name of channel %llu\n\n is: %s\n", (unsigned long long)newChannel_id, name);
    	ts3server_freeMemory(name);
	}
        if (CHECK_ERROR(ts3server_getChannelVariableAsString(server_id, newChannel_id, CHANNEL_TOPIC, &name)) == true)
	{
		printf("Topic of channel %llu\n\n is: %s\n", (unsigned long long)newChannel_id, name);
    	ts3server_freeMemory(name);
        }
        if (CHECK_ERROR(ts3server_getChannelVariableAsString(server_id, newChannel_id, CHANNEL_DESCRIPTION, &name)) == true)
	{
        printf("Description of channel %llu\n\n is: %s\n", (unsigned long long)newChannel_id, name);
    	ts3server_freeMemory(name);
	}

    /* Wait for user input */
    printf("\n--- Press Return to shutdown server and exit ---\n");
    getchar();

    /* Stop virtual server */
    CHECK_ERROR_FATAL(ts3server_stopVirtualServer(server_id));

    /* Shutdown server lib */
    CHECK_ERROR_FATAL(ts3server_destroyServerLib());

    return 0;
}

